from distutils.core import setup

setup(
    name='nester-mht',
    version='1.0.0',
    py_modules=['nester-mht'],
    author='Hitomeng',
    author_email='hitomeng@qq.com',
    url='http://www.headerfirstlabs.com',
    description='A simple printer for list',
)
